==> haskell-graphscc-1.0.4-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphscc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 GraphSCC
version:              1.0.4
visibility:           public
id:                   GraphSCC-1.0.4-FSKMhpdn5qIIadttVxD85p
key:                  GraphSCC-1.0.4-FSKMhpdn5qIIadttVxD85p
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
synopsis:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

description:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

category:             Algorithms
abi:                  1f1c2ff0f73f4313349f738db362152d
exposed:              True
exposed-modules:      Data.Graph.SCC
hidden-modules:       Data.Graph.ArraySCC
import-dirs:          /usr/lib/ghc-8.8.3/site-local/GraphSCC-1.0.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/GraphSCC-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/GraphSCC-1.0.4
hs-libraries:         HSGraphSCC-1.0.4-FSKMhpdn5qIIadttVxD85p
depends:              array-0.5.4.0 base-4.13.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-graphscc/html/GraphSCC.haddock
haddock-html:         /usr/share/doc/haskell-graphscc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphscc-1.0.4-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphscc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 GraphSCC
version:              1.0.4
visibility:           public
id:                   GraphSCC-1.0.4-IC6FF89rxYeGrQYTR5Pr4w
key:                  GraphSCC-1.0.4-IC6FF89rxYeGrQYTR5Pr4w
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
synopsis:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

description:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

category:             Algorithms
abi:                  21b75dc1b06c8ea00f9cee5c400dc40a
exposed:              True
exposed-modules:      Data.Graph.SCC
hidden-modules:       Data.Graph.ArraySCC
import-dirs:          /usr/lib/ghc-8.10.1/site-local/GraphSCC-1.0.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/GraphSCC-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/GraphSCC-1.0.4
hs-libraries:         HSGraphSCC-1.0.4-IC6FF89rxYeGrQYTR5Pr4w
depends:              array-0.5.4.0 base-4.14.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-graphscc/html/GraphSCC.haddock
haddock-html:         /usr/share/doc/haskell-graphscc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
